# log
from rrsdk.rqUtil.rqLogs import (rq_util_log_debug, rq_util_log_expection,
                                     rq_util_log_info)

# Parameter
from rrsdk.rqUtil.rqParameter import (
    PERIODS, SWL_LEVEL,MARKET_TYPE, FREQUENCE)

# singleton
from rrsdk.rqUtil.rqSingleton import (Singleton,Singleton_wraps) #,ConSqlDb)

# date
from rrsdk.rqUtil.rqDate import (rq_util_calc_time, rq_util_date_int2str,
                                     rq_util_date_stamp, rq_util_date_str2int,
                                     rq_util_date_today, rq_util_date_valid,
                                     rq_util_datetime_to_strdate,
                                     rq_util_stamp2datetime,
                                     rq_util_get_date_index,
                                     rq_util_tdxtimestamp,
                                     rq_util_get_index_date, rq_util_id2date,
                                     rq_util_is_trade, rq_util_ms_stamp,
                                     rq_util_realtime, rq_util_select_hours,
                                     rq_util_select_min, rq_util_time_delay,
                                     rq_util_time_now, rq_util_time_stamp,
                                     rq_util_to_datetime, rq_util_today_str,
                                     rqTZInfo_CN)

# trade date
from rrsdk.rqUtil.rqDate_trade import (rq_util_date_gap,
                                           rq_util_format_date2str,
                                           rq_util_future_to_realdatetime,
                                           rq_util_future_to_tradedatetime,
                                           rq_util_get_last_datetime,
                                           rq_util_get_last_day,
                                           rq_util_get_last_tradedate,
                                           rq_util_get_next_datetime,
                                           rq_util_get_next_day,
                                           rq_util_get_next_trade_date,
                                           rq_util_get_next_period,
                                           rq_util_get_order_datetime,
                                           rq_util_get_pre_trade_date,
                                           rq_util_get_real_date,
                                           rq_util_get_real_datelist,
                                           rq_util_get_trade_datetime,
                                           rq_util_get_trade_gap,
                                           rq_util_get_trade_range,
                                           rq_util_if_trade,
                                           rq_util_if_tradetime,
                                           rq_util_future_to_realdatetime,
                                           rq_util_future_to_tradedatetime,
                                           trade_date_sse)

if __name__ == '__main__':
    rq_util_log_info(rq_util_get_last_tradedate())
    rq_util_log_info(trade_date_sse)




import datetime
import threading
import time
import pandas as pd

from rrsdk.rqUtil.rqLogs import rq_util_log_info

rqTZInfo_CN = 'Asia/Shanghai'

def rq_util_time_now():
    """
    explanation:
       获取当前日期时间
    return:
        datetime
    """
    return datetime.datetime.now()

def rq_util_date_today():
    """
    explanation:
       获取当前日期
    return:
        date
    """
    return datetime.date.today()


def rq_util_today_str():
    """
    explanation:
        返回今天的日期字符串
    return:
        str
    """
    dt = rq_util_date_today()
    return rq_util_datetime_to_strdate(dt)


def rq_util_date_str2int(date):
    """
    explanation:
        转换日期字符串为整数
    params:
        * date->
            含义: 日期字符串
            类型: date
            参数支持: []
    demonstrate:
        print(rq_util_date_str2int("2011-09-11"))
    return:
        int
    output:
        >>20110911
    """
    # return int(str(date)[0:4] + str(date)[5:7] + str(date)[8:10])
    if isinstance(date, str):
        return int(str().join(date.split('-')))
    elif isinstance(date, int):
        return date


def rq_util_date_int2str(int_date):
    """
    explanation:
        转换日期整数为字符串
    params:
        * int_date->
            含义: 日期转换得
            类型: int
            参数支持: []
    return:
        str
    """
    date = str(int_date)
    if len(date) == 8:
        return str(date[0:4] + '-' + date[4:6] + '-' + date[6:8])
    elif len(date) == 10:
        return date


def rq_util_to_datetime(time):
    """
    explanation:
        转换字符串格式的日期为datetime
    params:
        * time->
            含义: 日期
            类型: str
            参数支持: []
    return:
        datetime
    """
    if len(str(time)) == 10:
        _time = '{} 00:00:00'.format(time)
    elif len(str(time)) == 19:
        _time = str(time)
    else:
        rq_util_log_info('WRONG DATETIME FORMAT {}'.format(time))
    return datetime.datetime.strptime(_time, '%Y-%m-%d %H:%M:%S')


def rq_util_datetime_to_strdate(dt):
    """
    explanation:
        转换字符串格式的日期为datetime
    params:
        * dt->
            含义: 日期时间
            类型: datetime
            参数支持: []
    return:
        str
    """
    strdate = "%04d-%02d-%02d" % (dt.year, dt.month, dt.day)
    return strdate


def rq_util_datetime_to_strdatetime(dt):
    """
    explanation:
        转换日期时间为字符串格式
    params:
        * dt->
            含义: 日期时间
            类型: datetime
            参数支持: []
    return:
        datetime
    """
    strdatetime = "%04d-%02d-%02d %02d:%02d:%02d" % (
        dt.year,
        dt.month,
        dt.day,
        dt.hour,
        dt.minute,
        dt.second
    )
    return strdatetime


def rq_util_date_stamp(date):
    """
    explanation:
        转换日期时间字符串为浮点数的时间戳
    params:
        * date->
            含义: 日期时间
            类型: str
            参数支持: []
    return:
        time
    """
    if not date:
        return date
    datestr = pd.Timestamp(date).strftime("%Y-%m-%d")
    date = time.mktime(time.strptime(datestr, '%Y-%m-%d'))
    return date


def rq_util_time_stamp(time_):
    """
    explanation:
       转换日期时间的字符串为浮点数的时间戳
    params:
        * time_->
            含义: 日期时间
            类型: str
            参数支持: ['2018-01-01 00:00:00']
    return:
        time
    """
    if len(str(time_)) == 10:
        # yyyy-mm-dd格式
        return time.mktime(time.strptime(time_, '%Y-%m-%d'))
    elif len(str(time_)) == 16:
        # yyyy-mm-dd hh:mm格式
        return time.mktime(time.strptime(time_, '%Y-%m-%d %H:%M'))
    else:
        timestr = str(time_)[0:19]
        return time.mktime(time.strptime(timestr, '%Y-%m-%d %H:%M:%S'))


def rq_util_tdxtimestamp(time_stamp):
    """
    explanation:
       转换tdx的realtimeQuote数据, [相关地址](https://github.com/rainx/pytdx/issues/187#issuecomment-441270487)
    params:
        * time_stamp->
            含义: 时间
            类型: str
            参数支持: []
    return:
        int
    """
    if time_stamp is not None:
        time_stamp = str(time_stamp)
        time = time_stamp[:-6] + ':'
        if int(time_stamp[-6:-4]) < 60:
            time += '%s:' % time_stamp[-6:-4]
            time += '%06.3f' % (
                int(time_stamp[-4:]) * 60 / 10000.0
            )
        else:
            time += '%02d:' % (
                int(time_stamp[-6:]) * 60 / 1000000
            )
            time += '%06.3f' % (
                (int(time_stamp[-6:]) * 60 % 1000000) * 60 / 1000000.0
            )
        return time


def rq_util_pands_timestamp_to_date(pandsTimestamp):
    """
    explanation:
        转换 pandas 的时间戳 到 datetime.date类型
    params:
        * pandsTimestamp->
            含义: pandas的时间戳
            类型:  pandas._libs.tslib.Timestamp
            参数支持: []
    return:
        date
    """
    return pandsTimestamp.to_pydatetime().date()


def rq_util_pands_timestamp_to_datetime(pandsTimestamp):
    """
    explanation:
        转换 pandas时间戳 到 datetime.datetime类型
    params:
        * pandsTimestamp->
            含义: pandas时间戳
            类型:  pandas._libs.tslib.Timestamp
            参数支持: []
    return:
        datetime
    """
    return pandsTimestamp.to_pydatetime()


def rq_util_stamp2datetime(timestamp):
    """
    explanation:
        datestamp转datetime,pandas转出来的timestamp是13位整数 要/1000,
        It’s common for this to be restricted to years from 1970 through 2038.
        从1970年开始的纳秒到当前的计数 转变成 float 类型时间 类似 time.time() 返回的类型
    params:
        * timestamp->
            含义: 时间戳
            类型: float
            参数支持: []
    return:
        datetime
    """
    try:
        return datetime.datetime.fromtimestamp(timestamp)
    except Exception as e:
        # it won't work ??
        try:
            return datetime.datetime.fromtimestamp(timestamp / 1000)
        except:
            try:
                return datetime.datetime.fromtimestamp(timestamp / 1000000)
            except:
                return datetime.datetime.fromtimestamp(timestamp / 1000000000)

    #


def rq_util_ms_stamp(ms):
    """
    explanation:
        直接返回不做处理
    params:
        * ms->
            含义: 时间戳
            类型: float
            参数支持: []
    return:
        float
    """

    return ms


def rq_util_date_valid(date):
    """
    explanation:
        判断字符串格式(1982-05-11)
    params:
        * date->
            含义: 日期
            类型: str
            参数支持: []
    return:
        bool
    """
    try:
        time.strptime(date, "%Y-%m-%d")
        return True
    except:
        return False


def rq_util_realtime(strtime, client):
    """
    explanation:
        查询数据库中的数据
    params:
        * strtime->
            含义: 日期
            类型: str
            参数支持: []
        * client->
            含义: 源
            类型: pymongo.MongoClient
            参数支持: []
    return:
        dict
    """
    time_stamp = rq_util_date_stamp(strtime)
    coll = client.rrshare.trade_date
    temp_str = coll.find_one({'date_stamp': {"$gte": time_stamp}})
    time_real = temp_str['date']
    time_id = temp_str['num']
    return {'time_real': time_real, 'id': time_id}


def rq_util_id2date(idx, client):
    """
    explanation:
         从数据库中查询通达信时间
    params:
        * idx->
            含义: 数据库index
            类型: str
            参数支持: []
        * client->
            含义: 源
            类型: pymongo.MongoClient
            参数支持: []
    return:
        str
    """
    coll = client.rrshare.trade_date
    temp_str = coll.find_one({'num': idx})
    return temp_str['date']


def rq_util_is_trade(date, code, client):
    """
    explanation:
        从数据库中查询判断是否是交易日
    params:
        * date->
            含义: 日期
            类型: str
            参数支持: []
        * code->
            含义: 代码
            类型: str
            参数支持: []
        * client->
            含义: 源
            类型: pymongo.MongoClient
            参数支持: []
    return:
        bool
    """
    coll = client.rrshare.stock_day
    date = str(date)[0:10]
    is_trade = coll.find_one({'code': code, 'date': date})
    try:
        len(is_trade)
        return True
    except:
        return False


def rq_util_get_date_index(date, trade_list):
    """
    explanation:
        返回在trade_list中的index位置
    params:
        * date->
            含义: 日期
            类型: str
            参数支持: []
        * trade_list->
            含义: 代码
            类型: ??
            参数支持: []
    return:
        ??
    """
    return trade_list.index(date)


def rq_util_get_index_date(id, trade_list):
    """
    explanation:
        根据id索引值
    params:
        * id->
            含义: 日期
            类型: str
            参数支持: []
        * trade_list->
            含义: 代码
            类型: dict
            参数支持: []
    return:
        ??
    """
    return trade_list[id]


def rq_util_select_hours(time=None, gt=None, lt=None, gte=None, lte=None):
    """
    explanation:
        rrshare的时间选择函数,约定时间的范围,比如早上9点到11点
    params:
        * time->
            含义: 时间
            类型: str
            参数支持: []
        * gt->
            含义: 大于
            类型: Any
            参数支持: []
        * lt->
            含义: 小于
            类型: Any
            参数支持: []
        * gte->
            含义: 大于等于
            类型: Any
            参数支持: []
        * lte->
            含义: 小于等于
            类型: Any
            参数支持: []
    return:
        bool
    """
    if time is None:
        __realtime = datetime.datetime.now()
    else:
        __realtime = time

    fun_list = []
    if gt != None:
        fun_list.append('>')
    if lt != None:
        fun_list.append('<')
    if gte != None:
        fun_list.append('>=')
    if lte != None:
        fun_list.append('<=')

    assert len(fun_list) > 0
    true_list = []
    try:
        for item in fun_list:
            if item == '>':
                if __realtime.strftime('%H') > gt:
                    true_list.append(0)
                else:
                    true_list.append(1)
            elif item == '<':
                if __realtime.strftime('%H') < lt:
                    true_list.append(0)
                else:
                    true_list.append(1)
            elif item == '>=':
                if __realtime.strftime('%H') >= gte:
                    true_list.append(0)
                else:
                    true_list.append(1)
            elif item == '<=':
                if __realtime.strftime('%H') <= lte:
                    true_list.append(0)
                else:
                    true_list.append(1)

    except:
        return Exception
    if sum(true_list) > 0:
        return False
    else:
        return True


def rq_util_select_min(time=None, gt=None, lt=None, gte=None, lte=None):
    """
    explanation:
        择分钟
    params:
        * time->
            含义: 时间
            类型: str
            参数支持: []
        * gt->
            含义: 大于等于
            类型: Any
            参数支持: []
        * lt->
            含义: 小于
            类型: Any
            参数支持: []
        * gte->
            含义: 大于等于
            类型: Any
            参数支持: []
        * lte->
            含义: 小于等于
            类型: Any
            参数支持: []
    return:
        bool
    """
    if time is None:
        __realtime = datetime.datetime.now()
    else:
        __realtime = time

    fun_list = []
    if gt != None:
        fun_list.append('>')
    if lt != None:
        fun_list.append('<')
    if gte != None:
        fun_list.append('>=')
    if lte != None:
        fun_list.append('<=')

    assert len(fun_list) > 0
    true_list = []
    try:
        for item in fun_list:
            if item == '>':
                if __realtime.strftime('%M') > gt:
                    true_list.append(0)
                else:
                    true_list.append(1)
            elif item == '<':
                if __realtime.strftime('%M') < lt:
                    true_list.append(0)
                else:
                    true_list.append(1)
            elif item == '>=':
                if __realtime.strftime('%M') >= gte:
                    true_list.append(0)
                else:
                    true_list.append(1)
            elif item == '<=':
                if __realtime.strftime('%M') <= lte:
                    true_list.append(0)
                else:
                    true_list.append(1)
    except:
        return Exception
    if sum(true_list) > 0:
        return False
    else:
        return True


def rq_util_time_delay(time_=0):
    """
    explanation:
        这是一个用于复用/比如说@装饰器的延时函数,使用threading里面的延时,为了是不阻塞进程,
        有时候,同时发进去两个函数,第一个函数需要延时,第二个不需要的话,用sleep就会阻塞掉第二个进程
    params:
        * time_->
            含义: 时间
            类型: time
            参数支持: []
    return:
        func
    """

    def _exec(func):
        threading.Timer(time_, func)

    return _exec


def rq_util_calc_time(func, *args, **kwargs):
    """
    explanation:
        耗时长度的装饰器
    params:
        * func ->
            含义: 被装饰的函数
            类型: func
            参数支持: []
        * args ->
            含义: 函数接受的任意元组参数
            类型: tuple
            参数支持: []
        * kwargs ->
            含义: 函数接受的任意字典参数
            类型: dict
            参数支持: []
    return:
        None
    """
    _time = datetime.datetime.now()
    func(*args, **kwargs)
    print(datetime.datetime.now() - _time)
    # return datetime.datetime.now() - _time


month_data = pd.date_range(
    '1/1/1996',
    '12/31/2023',
    freq='Q-MAR'
).astype(str).tolist()

if __name__ == '__main__':
    print(rq_util_time_stamp('2017-01-01 10:25:08'))



"""Console script for rrsdk."""

import fire


def help():
    print("rrsdk")
    print("=" * len("rrsdk"))
    print("Skeleton project created by Python Project Wizard (ppw)")


def main():
    fire.Fire({"help": help})


if __name__ == "__main__":
    main()  # pragma: no cover



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['rrsdk', 'rrsdk.rqFetch', 'rrsdk.rqUtil', 'tests']

package_data = \
{'': ['*']}

install_requires = \
['fire==0.4.0']

extras_require = \
{'dev': ['tox>=3.20.1,<4.0.0',
         'virtualenv>=20.2.2,<21.0.0',
         'pip>=20.3.1,<21.0.0',
         'twine>=3.3.0,<4.0.0',
         'pre-commit>=2.12.0,<3.0.0',
         'toml>=0.10.2,<0.11.0'],
 'doc': ['mkdocs>=1.1.2,<2.0.0',
         'mkdocs-include-markdown-plugin>=1.0.0,<2.0.0',
         'mkdocs-material>=6.1.7,<7.0.0',
         'mkdocstrings>=0.13.6,<0.14.0',
         'mkdocs-autorefs==0.1.1'],
 'test': ['black==20.8b1',
          'isort==5.6.4',
          'flake8==3.8.4',
          'flake8-docstrings>=1.6.0,<2.0.0',
          'pytest==6.1.2',
          'pytest-cov==2.10.1']}

entry_points = \
{'console_scripts': ['rrsdk = rrsdk.cli:main']}

setup_kwargs = {
    'name': 'rrsdk',
    'version': '0.1.2',
    'description': 'Skeleton project created by Python Project Wizard (ppw).',
    'long_description': '# rrsdk\n\n\n<p align="center">\n<a href="https://pypi.python.org/pypi/rrsdk">\n    <img src="https://img.shields.io/pypi/v/rrsdk.svg"\n        alt = "Release Status">\n</a>\n\n<a href="https://github.com/romepeng/rrsdk/actions">\n    <img src="https://github.com/romepeng/rrsdk/actions/workflows/main.yml/badge.svg?branch=release" alt="CI Status">\n</a>\n\n<a href="https://rrsdk.readthedocs.io/en/latest/?badge=latest">\n    <img src="https://readthedocs.org/projects/rrsdk/badge/?version=latest" alt="Documentation Status">\n</a>\n\n</p>\n\n\nSkeleton project created by Python Project Wizard (ppw)\n\n\n* Free software: MIT\n* Documentation: <https://rrsdk.readthedocs.io>\n\n\n## Features\n\n* TODO\n\n## Credits\n\nThis package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [zillionare/cookiecutter-pypackage](https://github.com/zillionare/cookiecutter-pypackage) project template.\n#\x00 \x00r\x00r\x00s\x00d\x00k\x00\n\x00\n\x00',
    'author': 'rome peng',
    'author_email': 'romepeng@outlook.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/romepeng/rrsdk',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8',
}


setup(**setup_kwargs)



# coding: utf-8
import requests
import json
import time
import pandas as pd

from rrsdk.rqUtil import rq_util_get_last_tradedate, rq_util_if_trade, rq_util_if_tradetime, rq_util_date_today

class Swsindex(object):
    """http://www.swsindex.com/idx0120.aspx?columnid=8832#
    industry class:
    http://www.swsindex.com/downloadfiles.aspx?swindexcode=SwClass&type=530&columnid=8892
    get sw industry index class and realtime quote from swsindex.com by post method.
    """
    
    def __init__(self):
        
        self.url = 'http://www.swsindex.com/handler.aspx'
        self.headers = {
            'Accept': 'application/json, text/javascript, */*',
            'Accept-Encoding': 'gzip, deflate',
            'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8',
            'Content-Length': '227',
            'Content-Type': 'application/x-www-form-urlencoded',
            'Cookie': 'ASP.NET_SessionId=l0zdjg2sww1yrfitod5trjuq',
            'Host': 'www.swsindex.com',
            'Origin': 'http://www.swsindex.com',
            'Proxy-Connection': 'keep-alive',  
            'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.212 Safari/537.36',
            'X-Requested-With': 'XMLHttpRequest'
            }


    def get_swsindex_L1_realtime(self):
        result = []
        for i in range(1,3):
            postdata = {
            'tablename': 'swzs',
            'key': 'L1',
            'p': '{}'.format(i),
            'where': "L1 in('801010','801020','801030','801040','801050','801080','801110','801120','801130','801140', \
                            '801150','801160','801170','801180','801200','801210','801230','801710','801720','801730',\
                            '801740','801750','801760','801770','801780','801790','801880','801890')",
            'orderby': '',
            'fieldlist': 'L1,L2,L3,L4,L5,L6,L7,L8,L11',
            'pagecount': '28',
            'timed': '{}'.format(int(time.time()*1000))
            ##其中页码p是变量，一共2页。timed也是变量，通过 time.time() 来获取时间戳然后将取值到千分位
            }
            self.headers['Referer'] = 'http://www.swsindex.com/idx0120.aspx?columnid=8832'
            #print(self.headers)
            req = requests.post(self.url, headers=self.headers, data=postdata)
            data = req.content.decode()
            data = data.replace("'",'"')
            data = json.loads(data)['root']
            #print(len(data))
            result.extend(data)
        df = pd.DataFrame(result)
        
        df.columns = ['index', 'name', 'pre_close', 'open', 'amount','high','low','close','vol' ]
        cols = ['pre_close', 'open', 'amount','high','low','close','vol']
        for i in cols:
            df[i] = pd.to_numeric(df[i], errors='coerce')
        df['name'] = df['name'].apply(lambda x : x.split()[0])
        #print(df.dtypes)
        df['pct_change'] = 0.00 if df['close'].values[0] == 0 else 100*(df['close']/ df['pre_close'] -1) 
        date_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
        #trade_time = #TODO
        trade_time = date_time if rq_util_if_trade else rq_util_get_last_tradedate() # TODO
        print(trade_time)
        df['trade_date'] = trade_time 
        return df.round(2)

    def get_index_name(self, out_type=dict):
        
        data = self.get_swsindex_L1_realtime()[['index', 'name']]
        if out_type == dict:
            data.set_index('index', inplace=True)
            return data.to_dict()['name']
        
        return data 


    def get_swl1_class_one(self,index='801010'):
        """http://www.swsindex.com/idx0210.aspx?swindexcode=801010
        """
        self.headers['Referer'] = 'http://www.swsindex.com/idx0210.aspx?swindexcode={}'.format(index)
        result = []
        for i in range(1, 100):
            postdata={
            'tablename': 'SwIndexConstituents',
            'key': 'id',
            'p': '{}'.format(i),
            'where': 'SwIndexCode={} and IsReserve =0 and  NewFlag=1'.format(index),
            'orderby': 'StockCode, BeginningDate_0',
            'fieldlist': 'stockcode,stockname,newweight,beginningdate',
            'pagecount': '92',
            'timed': '{}'.format(int(time.time()*1000))
            }
            #print(postdata)
            
            req = requests.post(self.url, headers=self.headers, data=postdata)
            data = req.content.decode()
            data = data.replace("'",'"')
            data = json.loads(data)['root']
            #print(len(data))
            if not len(data):
                break
            result.extend(data)
        df = pd.DataFrame(result)
        df.drop(columns=['newweight','beginningdate'], inplace=True)
        df['index_name'] = self.get_index_name(out_type=dict)[index] + '_L1'
        df.rename(columns={'stockcode': 'code','stockname':'name'}, inplace=True)
        return df


    def get_swl1_class(self):
        L1_INDEX = ['801010','801020','801030','801040','801050','801080','801110','801120','801130','801140', \
                            '801150','801160','801170','801180','801200','801210','801230','801710','801720','801730',\
                            '801740','801750','801760','801770','801780','801790','801880','801890']
        df = pd.DataFrame()
        for l in L1_INDEX:
            print(f'index code: {l}')
            one = self.get_swl1_class_one(l)
            one['index'] = l
            df = df.append(one)
        return df


if __name__ == '__main__':
    swi = Swsindex()
    #print(swi.url)
    #print(swi.headers)
    print(swi.get_swsindex_L1_realtime())  # ok
    print(swi.get_index_name())
    print(swi.get_swl1_class_one()) #pk
    #print(swi.get_swl1_class()) #ok
    pass



import json
import tushare as ts 

from rrsdk.rqUtil.config_setting import setting

try:
    token = setting['TSPRO_TOKEN']
    #ts.set_token(token)
    pro = ts.pro_api(token)
    #print('tushare token set ok , can use pro as api!')
except Exception as e:
    print(e)





"""
这里定义的是一些常用常量
"""
from enum import Enum
from pytz import timezone

CHINA_TZ = timezone("Asia/Shanghai")

MAX_QUERY_SIZE: int = 5000
TS_DATE_FORMATE: str = '%Y%m%d'
MAX_QUERY_TIMES: int = 500

class TRADE_TIMES():
    TRADE_TIME_AM = ['09:30:00','11:30:00']
    TRADE_TIME_PM = ["13:00:00","15:00:00"]
    TRADE_TIME_AM_pre = ['09:25:00','11:31:00']
    TRADE_TIME_PM_pre = ["13:00:00","15:01:00"]

#print(TRADE_TIMES().TRADE_TIME_AM)

class REPORT_PERIODS():
    q1 = '0331'
    q2 = '0630'
    q3 = '0930'
    q4 = '1231'
    REPORT_PERIODS_DICT = { 'q1': '0331',
            'q2': '0630',
            'q3': '0930',
            'q4': '1231'}
    
class PERIODS():
    """stock trade period
    """
    PERIODS=[5,10,20,60,120,250]

class SWL_LEVEL():
    LEVEL =['L1','L2','L3']
    SWL_LEVEL = ['sw_l1','sw_l2','sw_l3']

class FREQUENCE():
    """查询的级别
    YEAR = 'year'  # 年bar
    QUARTER = 'quarter'  # 季度bar
    MONTH = 'month'  # 月bar
    WEEK = 'week'  # 周bar
    DAY = 'day'  # 日bar
    ONE_MIN = '1min'  # 1min bar
    FIVE_MIN = '5min'  # 5min bar
    FIFTEEN_MIN = '15min'  # 15min bar
    THIRTY_MIN = '30min'  # 30min bar
    HOUR = '60min'  # 60min bar
    SIXTY_MIN = '60min'  # 60min bar
    TICK = 'tick'  # transaction
    ASKBID = 'askbid'  # 上下五档/一档
    REALTIME_MIN = 'realtime_min' # 实时分钟线
    LATEST = 'latest'  # 当前bar/latest
    2019/08/06 @yutiansut
    """

    YEAR = 'year'  # 年bar
    QUARTER = 'quarter'  # 季度bar
    MONTH = 'month'  # 月bar
    WEEK = 'week'  # 周bar
    DAY = 'day'  # 日bar
    ONE_MIN = '1min'  # 1min bar
    FIVE_MIN = '5min'  # 5min bar
    FIFTEEN_MIN = '15min'  # 15min bar
    THIRTY_MIN = '30min'  # 30min bar
    HOUR = '60min'  # 60min bar
    SIXTY_MIN = '60min'  # 60min bar
    TICK = 'tick'  # transaction
    ASKBID = 'askbid'  # 上下五档/一档
    REALTIME_MIN = 'realtime_min'  # 实时分钟线
    LATEST = 'latest'  # 当前bar/latest
   


class MARKET_TYPE():
    """市场种类
    日线 尾数01
    分钟线 尾数02
    tick 尾数03
    市场:
    股票 0
    指数/基金 1
    期货 2
    港股 3
    美股 4
    比特币/加密货币市场 5
    """
    STOCK_CN = 'stock_cn'  # 中国A股
    STOCK_CN_B = 'stock_cn_b'  # 中国B股
    STOCK_CN_D = 'stock_cn_d'  # 中国D股 沪伦通
    STOCK_HK = 'stock_hk'  # 港股
    STOCK_US = 'stock_us'  # 美股
    FUTURE_CN = 'future_cn'  # 国内期货
    OPTION_CN = 'option_cn'  # 国内期权
    STOCKOPTION_CN = 'stockoption_cn'  # 个股期权
    # BITCOIN = 'bitcoin'  # 比特币
    CRYPTOCURRENCY = 'cryptocurrency'  # 加密货币(衍生货币)
    INDEX_CN = 'index_cn'  # 中国指数
    FUND_CN = 'fund_cn'   # 中国基金
    BOND_CN = 'bond_cn'  # 中国债券
    
